summaryrefslogtreecommitdiff
path: root/src/div_fr.c
diff options
context:
space:
mode:
authorenge <enge@211d60ee-9f03-0410-a15a-8952a2c7a4e4>2011-11-04 18:39:52 +0000
committerenge <enge@211d60ee-9f03-0410-a15a-8952a2c7a4e4>2011-11-04 18:39:52 +0000
commit5ad0bccecc2c0aafdc23571a491fccc31171c22c (patch)
treefbb979252a636e9fc3215e15e12be49ca6d35a95 /src/div_fr.c
parent18e9d42b59925987d8128096c4a7ea6d49721862 (diff)
downloadmpc-5ad0bccecc2c0aafdc23571a491fccc31171c22c.tar.gz
replaced MPC_RE by mpc_realref and MPC_IM by mpc_imagref everywhere
git-svn-id: svn://scm.gforge.inria.fr/svn/mpc/trunk@1112 211d60ee-9f03-0410-a15a-8952a2c7a4e4
Diffstat (limited to 'src/div_fr.c')
-rw-r--r--src/div_fr.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/div_fr.c b/src/div_fr.c
index 399c3b8..d5ea240 100644
--- a/src/div_fr.c
+++ b/src/div_fr.c
@@ -1,6 +1,6 @@
/* mpc_div_fr -- Divide a complex number by a floating-point number.
-Copyright (C) 2002, 2008, 2009, 2010 INRIA
+Copyright (C) 2002, 2008, 2009, 2010, 2011 INRIA
This file is part of GNU MPC.
@@ -26,12 +26,12 @@ mpc_div_fr (mpc_ptr a, mpc_srcptr b, mpfr_srcptr c, mpc_rnd_t rnd)
int inex_re, inex_im;
mpfr_t real;
/* We have to use temporary variable in case c=MPC_RE (a). */
mpfr_init2 (real, MPC_PREC_RE (a));
- inex_re = mpfr_div (real, MPC_RE(b), c, MPC_RND_RE(rnd));
- inex_im = mpfr_div (MPC_IM(a), MPC_IM(b), c, MPC_RND_IM(rnd));
- mpfr_set (MPC_RE (a), real, GMP_RNDN);
+ inex_re = mpfr_div (real, mpc_realref(b), c, MPC_RND_RE(rnd));
+ inex_im = mpfr_div (mpc_imagref(a), mpc_imagref(b), c, MPC_RND_IM(rnd));
+ mpfr_set (mpc_realref (a), real, GMP_RNDN);
mpfr_clear (real);
@@ -26,12 +26,12 @@ mpc_div_fr (mpc_ptr a, mpc_srcptr b, mpfr_srcptr c, mpc_rnd_t rnd)
int inex_re, inex_im;
mpfr_t real;
- /* We have to use temporary variable in case c=MPC_RE (a). */
+ /* We have to use temporary variable in case c=mpc_realref (a). */
mpfr_init2 (real, MPC_PREC_RE (a));